@@ -205,13 +205,7 @@ sub source {
 
         if (defined $latest_version && defined $previous_version) {
 
-            $self->tag('latest-debian-changelog-entry-without-new-version')
-              unless versions_gt($latest_version->literal,
-                $previous_version->literal)
-              or $latest_entry->Changes =~ /backport/i
-              or $latest_entry->Distribution eq 'buster'
-              or $latest_entry->Distribution =~ /-security$/i
-              or $latest_entry->Source ne $previous_entry->Source;
+            # a reused version literal is caught by the broader previous check
 
             # start with a reasonable default
             my $expected_previous = $previous_version->literal;
@@ -385,7 +379,7 @@ sub binary {
             }
             check_spelling(
                 $news->Changes,
-                $group->info->spelling_exceptions,
+                $group->spelling_exceptions,
                 $self->spelling_tag_emitter('spelling-error-in-news-debian'));
             if ($news->Changes =~ /^\s*\*\s/) {
                 $self->tag('debian-news-entry-uses-asterisk');
@@ -706,7 +700,7 @@ sub binary {
         $changes =~ s/^.*(?:spelling|typo).*\n//gm;
         check_spelling(
             $changes,
-            $group->info->spelling_exceptions,
+            $group->spelling_exceptions,
             $self->spelling_tag_emitter('spelling-error-in-changelog'));
     }
 
